dreamtim API documentation
Description: This is the package with useful functions for personal usage

# Package `dreamtim`

This is the package with useful functions for personal usage

Expand source code

    """This is the package with useful functions for personal usage"""

    __version__ = "0.2.0"

## Sub-modules

`dreamtim.calculator`

  This module contains only one class - Calculator …

`dreamtim.statistical_tools`

  This module contains different self-implemented statistical tools. It isn't documented good, because I am lazy ;)

`dreamtim.test_calculator`

  Tests for calculator module.